# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class CampaignProbeDto(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'user_id': 'str',
        'name': 'str',
        'local_part': 'str',
        'email_address': 'str',
        'enabled': 'bool',
        'interval_seconds': 'int',
        'scheduling_enabled': 'bool',
        'next_run_at': 'datetime',
        'last_run_status': 'str',
        'last_health_score': 'int',
        'last_ingest_at': 'datetime',
        'total_ingest_count': 'int',
        'created_at': 'datetime',
        'updated_at': 'datetime'
    }

    attribute_map = {
        'id': 'id',
        'user_id': 'userId',
        'name': 'name',
        'local_part': 'localPart',
        'email_address': 'emailAddress',
        'enabled': 'enabled',
        'interval_seconds': 'intervalSeconds',
        'scheduling_enabled': 'schedulingEnabled',
        'next_run_at': 'nextRunAt',
        'last_run_status': 'lastRunStatus',
        'last_health_score': 'lastHealthScore',
        'last_ingest_at': 'lastIngestAt',
        'total_ingest_count': 'totalIngestCount',
        'created_at': 'createdAt',
        'updated_at': 'updatedAt'
    }

    def __init__(self, id=None, user_id=None, name=None, local_part=None, email_address=None, enabled=None, interval_seconds=None, scheduling_enabled=None, next_run_at=None, last_run_status=None, last_health_score=None, last_ingest_at=None, total_ingest_count=None, created_at=None, updated_at=None, local_vars_configuration=None):  # noqa: E501
        """CampaignProbeDto - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._user_id = None
        self._name = None
        self._local_part = None
        self._email_address = None
        self._enabled = None
        self._interval_seconds = None
        self._scheduling_enabled = None
        self._next_run_at = None
        self._last_run_status = None
        self._last_health_score = None
        self._last_ingest_at = None
        self._total_ingest_count = None
        self._created_at = None
        self._updated_at = None
        self.discriminator = None

        self.id = id
        self.user_id = user_id
        if name is not None:
            self.name = name
        self.local_part = local_part
        self.email_address = email_address
        self.enabled = enabled
        if interval_seconds is not None:
            self.interval_seconds = interval_seconds
        self.scheduling_enabled = scheduling_enabled
        if next_run_at is not None:
            self.next_run_at = next_run_at
        if last_run_status is not None:
            self.last_run_status = last_run_status
        if last_health_score is not None:
            self.last_health_score = last_health_score
        if last_ingest_at is not None:
            self.last_ingest_at = last_ingest_at
        self.total_ingest_count = total_ingest_count
        self.created_at = created_at
        self.updated_at = updated_at

    @property
    def id(self):
        """Gets the id of this CampaignProbeDto.  # noqa: E501


        :return: The id of this CampaignProbeDto.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this CampaignProbeDto.


        :param id: The id of this CampaignProbeDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and id is None:  # noqa: E501
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def user_id(self):
        """Gets the user_id of this CampaignProbeDto.  # noqa: E501


        :return: The user_id of this CampaignProbeDto.  # noqa: E501
        :rtype: str
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """Sets the user_id of this CampaignProbeDto.


        :param user_id: The user_id of this CampaignProbeDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and user_id is None:  # noqa: E501
            raise ValueError("Invalid value for `user_id`, must not be `None`")  # noqa: E501

        self._user_id = user_id

    @property
    def name(self):
        """Gets the name of this CampaignProbeDto.  # noqa: E501


        :return: The name of this CampaignProbeDto.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this CampaignProbeDto.


        :param name: The name of this CampaignProbeDto.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def local_part(self):
        """Gets the local_part of this CampaignProbeDto.  # noqa: E501


        :return: The local_part of this CampaignProbeDto.  # noqa: E501
        :rtype: str
        """
        return self._local_part

    @local_part.setter
    def local_part(self, local_part):
        """Sets the local_part of this CampaignProbeDto.


        :param local_part: The local_part of this CampaignProbeDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and local_part is None:  # noqa: E501
            raise ValueError("Invalid value for `local_part`, must not be `None`")  # noqa: E501

        self._local_part = local_part

    @property
    def email_address(self):
        """Gets the email_address of this CampaignProbeDto.  # noqa: E501


        :return: The email_address of this CampaignProbeDto.  # noqa: E501
        :rtype: str
        """
        return self._email_address

    @email_address.setter
    def email_address(self, email_address):
        """Sets the email_address of this CampaignProbeDto.


        :param email_address: The email_address of this CampaignProbeDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and email_address is None:  # noqa: E501
            raise ValueError("Invalid value for `email_address`, must not be `None`")  # noqa: E501

        self._email_address = email_address

    @property
    def enabled(self):
        """Gets the enabled of this CampaignProbeDto.  # noqa: E501


        :return: The enabled of this CampaignProbeDto.  # noqa: E501
        :rtype: bool
        """
        return self._enabled

    @enabled.setter
    def enabled(self, enabled):
        """Sets the enabled of this CampaignProbeDto.


        :param enabled: The enabled of this CampaignProbeDto.  # noqa: E501
        :type: bool
        """
        if self.local_vars_configuration.client_side_validation and enabled is None:  # noqa: E501
            raise ValueError("Invalid value for `enabled`, must not be `None`")  # noqa: E501

        self._enabled = enabled

    @property
    def interval_seconds(self):
        """Gets the interval_seconds of this CampaignProbeDto.  # noqa: E501


        :return: The interval_seconds of this CampaignProbeDto.  # noqa: E501
        :rtype: int
        """
        return self._interval_seconds

    @interval_seconds.setter
    def interval_seconds(self, interval_seconds):
        """Sets the interval_seconds of this CampaignProbeDto.


        :param interval_seconds: The interval_seconds of this CampaignProbeDto.  # noqa: E501
        :type: int
        """

        self._interval_seconds = interval_seconds

    @property
    def scheduling_enabled(self):
        """Gets the scheduling_enabled of this CampaignProbeDto.  # noqa: E501


        :return: The scheduling_enabled of this CampaignProbeDto.  # noqa: E501
        :rtype: bool
        """
        return self._scheduling_enabled

    @scheduling_enabled.setter
    def scheduling_enabled(self, scheduling_enabled):
        """Sets the scheduling_enabled of this CampaignProbeDto.


        :param scheduling_enabled: The scheduling_enabled of this CampaignProbeDto.  # noqa: E501
        :type: bool
        """
        if self.local_vars_configuration.client_side_validation and scheduling_enabled is None:  # noqa: E501
            raise ValueError("Invalid value for `scheduling_enabled`, must not be `None`")  # noqa: E501

        self._scheduling_enabled = scheduling_enabled

    @property
    def next_run_at(self):
        """Gets the next_run_at of this CampaignProbeDto.  # noqa: E501


        :return: The next_run_at of this CampaignProbeDto.  # noqa: E501
        :rtype: datetime
        """
        return self._next_run_at

    @next_run_at.setter
    def next_run_at(self, next_run_at):
        """Sets the next_run_at of this CampaignProbeDto.


        :param next_run_at: The next_run_at of this CampaignProbeDto.  # noqa: E501
        :type: datetime
        """

        self._next_run_at = next_run_at

    @property
    def last_run_status(self):
        """Gets the last_run_status of this CampaignProbeDto.  # noqa: E501


        :return: The last_run_status of this CampaignProbeDto.  # noqa: E501
        :rtype: str
        """
        return self._last_run_status

    @last_run_status.setter
    def last_run_status(self, last_run_status):
        """Sets the last_run_status of this CampaignProbeDto.


        :param last_run_status: The last_run_status of this CampaignProbeDto.  # noqa: E501
        :type: str
        """
        allowed_values = ["HEALTHY", "WARNING", "FAILED"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and last_run_status not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `last_run_status` ({0}), must be one of {1}"  # noqa: E501
                .format(last_run_status, allowed_values)
            )

        self._last_run_status = last_run_status

    @property
    def last_health_score(self):
        """Gets the last_health_score of this CampaignProbeDto.  # noqa: E501


        :return: The last_health_score of this CampaignProbeDto.  # noqa: E501
        :rtype: int
        """
        return self._last_health_score

    @last_health_score.setter
    def last_health_score(self, last_health_score):
        """Sets the last_health_score of this CampaignProbeDto.


        :param last_health_score: The last_health_score of this CampaignProbeDto.  # noqa: E501
        :type: int
        """

        self._last_health_score = last_health_score

    @property
    def last_ingest_at(self):
        """Gets the last_ingest_at of this CampaignProbeDto.  # noqa: E501


        :return: The last_ingest_at of this CampaignProbeDto.  # noqa: E501
        :rtype: datetime
        """
        return self._last_ingest_at

    @last_ingest_at.setter
    def last_ingest_at(self, last_ingest_at):
        """Sets the last_ingest_at of this CampaignProbeDto.


        :param last_ingest_at: The last_ingest_at of this CampaignProbeDto.  # noqa: E501
        :type: datetime
        """

        self._last_ingest_at = last_ingest_at

    @property
    def total_ingest_count(self):
        """Gets the total_ingest_count of this CampaignProbeDto.  # noqa: E501


        :return: The total_ingest_count of this CampaignProbeDto.  # noqa: E501
        :rtype: int
        """
        return self._total_ingest_count

    @total_ingest_count.setter
    def total_ingest_count(self, total_ingest_count):
        """Sets the total_ingest_count of this CampaignProbeDto.


        :param total_ingest_count: The total_ingest_count of this CampaignProbeDto.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and total_ingest_count is None:  # noqa: E501
            raise ValueError("Invalid value for `total_ingest_count`, must not be `None`")  # noqa: E501

        self._total_ingest_count = total_ingest_count

    @property
    def created_at(self):
        """Gets the created_at of this CampaignProbeDto.  # noqa: E501


        :return: The created_at of this CampaignProbeDto.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this CampaignProbeDto.


        :param created_at: The created_at of this CampaignProbeDto.  # noqa: E501
        :type: datetime
        """
        if self.local_vars_configuration.client_side_validation and created_at is None:  # noqa: E501
            raise ValueError("Invalid value for `created_at`, must not be `None`")  # noqa: E501

        self._created_at = created_at

    @property
    def updated_at(self):
        """Gets the updated_at of this CampaignProbeDto.  # noqa: E501


        :return: The updated_at of this CampaignProbeDto.  # noqa: E501
        :rtype: datetime
        """
        return self._updated_at

    @updated_at.setter
    def updated_at(self, updated_at):
        """Sets the updated_at of this CampaignProbeDto.


        :param updated_at: The updated_at of this CampaignProbeDto.  # noqa: E501
        :type: datetime
        """
        if self.local_vars_configuration.client_side_validation and updated_at is None:  # noqa: E501
            raise ValueError("Invalid value for `updated_at`, must not be `None`")  # noqa: E501

        self._updated_at = updated_at

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CampaignProbeDto):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CampaignProbeDto):
            return True

        return self.to_dict() != other.to_dict()
